@@ -2,6 +2,7 @@ import click
 
 from kks.cmd.build import build
 from kks.util.click import GroupedGroup
+from kks.util.common import config_directory
 from kks.cmd.auth import auth
 from kks.cmd.convert import convert
 from kks.cmd.deadlines import deadlines
@@ -20,10 +21,17 @@ from kks.cmd.top import top
 from kks.cmd.upgrade import upgrade, update
 
 
+def cleanup():
+    for filename in ['storage.pickle']:
+        file = config_directory() / filename
+        if file.exists():
+            file.unlink()
+
+
 @click.group(cls=GroupedGroup)
 def cli():
     """KoKoS helper tool"""
-    pass
+    cleanup()
 
 
 class Commands:
