@@ -39,7 +39,6 @@ GROUP_ID_BY_CONTEST = {
 
 
 PROBLEM_INFO_VERSION = 3
-TIME_FORMAT = '%Y/%m/%d %H:%M:%S'
 MSK_TZ = timezone(timedelta(hours=3))
 
 
@@ -138,6 +137,12 @@ def _skip_field(parser=None):
         meta['parser'] = parser
     return field(init=False, repr=False, compare=False, metadata=meta)
 
+def _parse_datetime(text: str, required_parts: Optional[int] = None):
+    parts = re.findall(r'\d+', text)
+    if required_parts is not None and len(parts) < required_parts:
+        raise ValueError(f'Expected datetime with at least {required_parts} parts, but got {len(parts)}')
+    return datetime(*map(int, parts))
+
 
 def _parse_field(parser):
     return field(metadata={'parser': parser})
@@ -158,7 +163,7 @@ class _CellParsers:
     @staticmethod
     def submission_time(cell):
         # NOTE timezone is not set
-        return datetime.strptime(cell.text, TIME_FORMAT)
+        return _parse_datetime(cell.text, 6)
 
     @staticmethod
     def submission_tests(cell):
@@ -381,8 +386,8 @@ class Deadlines:
     @staticmethod
     def parse(text, server_tz):
         """Parse datetime string (obtained from a problem page) and convert it to UTC"""
-        # YYYY//MM/DD [hh[:mm[:ss]]]
-        dt = datetime(*map(int, re.findall(r'\d+', text)))
+        # YYYY(/|-)MM(/|-)DD [hh[:mm[:ss]]]
+        dt = _parse_datetime(text, 3)
         return dt.replace(tzinfo=server_tz).astimezone(MSK_TZ)
 
 
@@ -774,7 +779,7 @@ def ejudge_timezone(session):
             continue
         key, value, *_ = cells
         if 'Server time' in key.text:
-            server_time = datetime.strptime(value.text, TIME_FORMAT)
+            server_time = _parse_datetime(value.text, 6)
             utc_time = datetime.utcnow()
             offset_hours = round((server_time - utc_time).total_seconds() / 3600)
             break
